==> nextcloud-app-deck-1%3A1.9.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/br.js <==
OC.L10N.register(
    "deck",
    {
    "Personal" : "Personel",
    "Finished" : "Achuet",
    "copy" : "eil",
    "Done" : "Graet",
    "Invalid date, date format must be YYYY-MM-DD" : "Deizat fall, stumm an deizat a zo ret bezhañ BBBB-MM-DD",
    "Cancel" : "Arrest",
    "Close" : "Seriñ",
    "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
    "Details" : "Munudoù",
    "Sharing" : "Rannan",
    "Tags" : "Klavioù",
    "Can edit" : "Posuple eo embann",
    "Can share" : "Galout a ra rannañ",
    "Owner" : "Perc'henner",
    "Delete" : "Dilemel",
    "Transfer" : "Treuzkas",
    "Edit" : "Cheñch",
    "Upload new files" : "Pelkas ur restr nevez",
    "Share from Files" : "Rannañ diouzh Restroù",
    "Download" : "Pellgargañ",
    "File to share" : "Restr da rannañ",
    "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
    "Comments" : "Displegadennoù",
    "Modified" : "Cheñchet",
    "Today" : "Hiziv",
    "Tomorrow" : "Warc'hoaz",
    "Next week" : "Sizhun a zeu",
    "Next month" : "Miz a zeu",
    "Save" : "Enrollañ",
    "Reply" : "Respont",
    "Update" : "Adnevesaat",
    "Description" : "Diskrivadur",
    "(group)" : "(strollad)",
    "seconds ago" : "eilenn zo",
    "Shared with you" : "Rannet ganeoc'h",
    "No notifications" : "Kemenaden ebet",
    "Share" : "Rannan"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-app-deck-1%3A1.14.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/br.js <==
OC.L10N.register(
    "deck",
    {
    "Personal" : "Personel",
    "Finished" : "Achuet",
    "copy" : "eil",
    "Done" : "Graet",
    "The file was uploaded" : "Kaset eo bet ar restr",
    "No file was uploaded" : "N'eus restr ebet a zo bet kaset",
    "Invalid date, date format must be YYYY-MM-DD" : "Deizat fall, stumm an deizat a zo ret bezhañ BBBB-MM-DD",
    "Cancel" : "Arrest",
    "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
    "Open" : "Digeriñ",
    "Completed" : "Achuet",
    "Details" : "Munudoù",
    "Sharing" : "Rannan",
    "Tags" : "Klavioù",
    "Activity" : "Obererezh",
    "Can edit" : "Posuple eo embann",
    "Can share" : "Galout a ra rannañ",
    "Owner" : "Perc'henner",
    "Delete" : "Dilemel",
    "Transfer" : "Treuzkas",
    "Edit" : "Cheñch",
    "Upload new files" : "Pelkas ur restr nevez",
    "Share from Files" : "Rannañ diouzh Restroù",
    "Download" : "Pellgargañ",
    "File to share" : "Restr da rannañ",
    "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
    "Comments" : "Displegadennoù",
    "Modified" : "Cheñchet",
    "Created" : "Krouet",
    "Save" : "Enrollañ",
    "Reply" : "Respont",
    "Update" : "Adnevesaat",
    "Created:" : "Krouet :",
    "Description" : "Diskrivadur",
    "(group)" : "(strollad)",
    "seconds ago" : "eilenn zo",
    "Search" : "Klask",
    "Shared with you" : "Rannet ganeoc'h",
    "No notifications" : "Kemennadenn ebet",
    "Today" : "Hiziv",
    "Tomorrow" : "Warc'hoaz",
    "Close" : "Seriñ",
    "Share" : "Rannan"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
